@@ -67,7 +67,11 @@ public:
     void defaults() override;
 
 #if QT_VERSION_MAJOR < 6
-    void setNeedsSave(bool needs) {emit changed(needs);}
+    void setNeedsSave(bool needs) {
+        m_needsSave = needs;
+        emit changed(needs);
+    }
+    bool needsSave() const {return m_needsSave;}
 #endif
 
 private Q_SLOTS:
@@ -93,6 +97,9 @@ private:
     QStringList mDeletedDomains;
     typedef QList<CookieProp *> CookiePropList;
     QHash<QString, CookiePropList> mDeletedCookies;
+#if QT_VERSION_MAJOR < 6
+    bool m_needsSave = false;
+#endif
 };
 
 #endif // KCOOKIESMANAGEMENT_H
