@@ -67,13 +67,18 @@
 
 using namespace KonqInterfaces;
 
-#ifdef KActivities_FOUND
 QString KonquerorApplication::currentActivity()
 {
+#ifdef KActivities_FOUND
     KonquerorApplication* app = qobject_cast<KonquerorApplication*>(QApplication::instance());
-    return app ? app->m_activityConsumer->currentActivity() : QString();
-}
+    if (!app || !app->m_activityConsumer || app->m_activityConsumer->serviceStatus() != KActivities::Consumer::Running) {
+        return QString();
+    }
+    return app->m_activityConsumer->currentActivity();
+#else
+    return QString();
 #endif
+}
 
 KonquerorApplication::KonquerorApplication(int &argc, char **argv)
     : QApplication(argc, argv), m_browser(nullptr)
