@@ -1710,3 +1710,12 @@ void KonqView::duplicateView(KonqView* otherView)
     };
     connect(j, &KJob::result, this, doOpening);
 }
+
+#if QT_VERSION_MAJOR >= 6
+void KonqView::forceWebEnginePartFocus()
+{
+    setFocus();
+    disconnect(m_pPart, &KParts::ReadOnlyPart::completed, this, &KonqView::forceWebEnginePartFocus);
+    disconnect(m_pPart, &KParts::ReadOnlyPart::completedWithPendingAction, this, &KonqView::forceWebEnginePartFocus);
+}
+#endif
